ConsumerIdentity class

Constructors

ConsumerIdentity({required String sessionId, required String providerId, required String appId, String source = _defaultConsumerIdentitySource})
const

Properties

appId String
final
hashCode int
The hash code for this object.
no setteroverride
providerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
source String
final

Methods

copyWith({String? sessionId, String? providerId, String? appId, String? source}) ConsumerIdentity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override