LogEntry class

Constructors

LogEntry({required ConsumerIdentity consumerIdentity, required String logLine, required int sequence, required String type, DateTime? time})

Properties

consumerIdentity ConsumerIdentity
final
hashCode int
The hash code for this object.
no setterinherited
logLine String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
final
time DateTime
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited