WebviewScreenState class

Inheritance

Constructors

WebviewScreenState()

Properties

claimCreationStarted bool
getter/setter pair
consecutiveNonLoginUrls int
getter/setter pair
context BuildContext
The location in the tree where this widget builds.
no setterinherited
cookiePersist bool
getter/setter pair
gestureRecognizers Set<Factory<OneSequenceGestureRecognizer>>
final
hashCode int
The hash code for this object.
no setterinherited
loading bool
getter/setter pair
logger ReclaimLogger
latefinal
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webViewController ↔ InAppWebViewController?
getter/setter pair
webViewKey GlobalKey<State<StatefulWidget>>
final
widget WebviewScreen
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
checkLoginUrl(String url) → void
createIntercepterInjection() String
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant WebviewScreen oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
extractRequestBodyTemplateParams(dynamic proofData, Map<String, String> params) → void
extractUrlTemplateParams(dynamic proofData, Map<String, String> params) → void
generateResponseMatch(String response, List<ResponseSelection> responseSelections, Map<String, String> params) Future<(List<ResponseRedaction>, List<ResponseMatch>)>
getCookieString(WebUri url) → dynamic
handleWebviewDebuglogs(dynamic args) → dynamic
handleWebviewErrorLogs(dynamic args) → dynamic
initState() → void
Called when this object is inserted into the tree.
override
markClaimCreationStarted() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
submitManualVerificationData(BuildContext context) → void
timedTriggerManualVerification(int time) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
triggerManualVerification() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited