Utils class

Constructors

Utils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

LOW_RAM_THRESHOLD int
getter/setter pair

Static Methods

advancedFutureHandler<T>(Future<T> future, {Duration? timeout}) Future<AdvancedFutureHandlerResult<T>>
createManualVerificationSession(CreateManualVerificationSessionPayload payload) Future<void>
dumpNetworkRequests(String sessionId, List<RequestLog> requestLogs) Future<void>
extractHost(String url) String
fetchProvider(String providerId, String appId, String timestamp, String signature) Future<HttpProvider>
generatePrivateKey() String
getAppInfo(String appId) Future<AppInfo>
getPublicIp() Future<String>
isDeviceLowRam() Future<bool>
isLoginUrl(String url) bool
safeLaunchUrl(String url) → void
sendLogs({required String sessionId, required String providerId, required String logType, String? applicationId}) Future<void>
signMap(Map<String, dynamic> mp, String key) → dynamic
substituteParams(String template, Map<String, String> params) String
truncateUrl(String url, int maxLength) String
updateSession(String sessionId, SessionStatus status) Future<void>