ClaimCreationBottomSheet class

Inheritance

Constructors

ClaimCreationBottomSheet({Key? key, required String sessionId, required String context, required String privateKey, required bool autoSubmit, required dynamic publicData, required String hostUrl, required AppInfo appInfo, required bool isDeviceLowRam, required HttpProvider providerData, required ExtractedData extractedData, required WitnessWebview witnessWebview, required ValueChanged<CreateClaimOutput> onProofShared, required void triggerManualVerification()})
const

Properties

appInfo AppInfo
final
autoSubmit bool
final
context String
final
extractedData ExtractedData
final
hashCode int
The hash code for this object.
no setterinherited
hostUrl String
final
isDeviceLowRam bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onProofShared ValueChanged<CreateClaimOutput>
final
privateKey String
final
providerData HttpProvider
final
publicData → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
triggerManualVerification → void Function()
final
witnessWebview WitnessWebview
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ClaimCreationBottomSheetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited