ComputeProofForWitnessCallback typedef

ComputeProofForWitnessCallback = Future<String> Function(String type, Uint8List bytes)

A callback that will be used by the witness webview to compute proof.

If this is null, the default prover is used.

Implementation

typedef ComputeProofForWitnessCallback = Future<String> Function(
  String type,
  Uint8List bytes,
);